@@ -1,30 +1,18 @@
 /*
- *   Copyright (C) 2008 Petri Damstén <damu@iki.fi>
+ *   SPDX-FileCopyrightText: 2008 Petri Damstén <damu@iki.fi>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-only
  */
 
 #include "comicproviderkross.h"
 #include "comic_package.h"
-#include <KPluginFactory>
 #include <KPackage/PackageLoader>
 
 KPackage::PackageStructure *ComicProviderKross::m_packageStructure(nullptr);
 
 ComicProviderKross::ComicProviderKross(QObject *parent, const QVariantList &args)
-    : ComicProvider(parent, args), m_wrapper(this)
+    : ComicProvider(parent, args)
+    , m_wrapper(this)
 {
 }
 
@@ -88,7 +76,7 @@ QString ComicProviderKross::nextIdentifier() const
 
 QString ComicProviderKross::previousIdentifier() const
 {
-    return  identifierToString(m_wrapper.previousIdentifierVariant());
+    return identifierToString(m_wrapper.previousIdentifierVariant());
 }
 
 QString ComicProviderKross::firstStripIdentifier() const
@@ -129,6 +117,6 @@ KPackage::PackageStructure *ComicProviderKross::packageStructure()
     return m_packageStructure;
 }
 
-//K_PLUGIN_FACTORY_WITH_JSON(ComicProviderKrossFactory, "plasma-packagestructure-comic.json", registerPlugin<ComicProviderKross>();)
+// K_PLUGIN_FACTORY_WITH_JSON(ComicProviderKrossFactory, "plasma-packagestructure-comic.json", registerPlugin<ComicProviderKross>();)
 
 // #include "comicproviderkross.moc"
