@@ -74,6 +74,6 @@ void CharacterRunner::run(const Plasma::RunnerContext &context, const Plasma::Qu
     QGuiApplication::clipboard()->setText(match.data().toString());
 }
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(CharacterRunner, "plasma-runner-character.json")
+K_PLUGIN_CLASS_WITH_JSON(CharacterRunner, "plasma-runner-character.json")
 
 #include "charrunner.moc"
